pub struct SelectionVector { /* private fields */ }Expand description
Logical selection over a ValueVector / DataChunk.
None indices = identity selection [0, 1, 2, …, N-1].
Implementations
Sourceimpl SelectionVector
impl SelectionVector
Sourcepub fn from_indices(indices: Vec<u32>) -> Self
pub fn from_indices(indices: Vec<u32>) -> Self
Explicit subset of physical row indices.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn is_identity(&self) -> bool
pub fn is_identity(&self) -> bool
Returns true when this is an identity selection (no indirection).
Sourcepub fn indices_ptr(&self) -> *const u32
pub fn indices_ptr(&self) -> *const u32
Raw pointer to the indices array, or null for identity selection (for JIT).